@@ -7,7 +7,7 @@ from importlib import metadata as importlib_metadata
 
 from .biased_random_walk import BiasedRandomWalk, RandomWalks
 from .dynnode2vec import DynNode2Vec, Embedding
-from .utils import generate_dynamic_graphs
+from .utils import create_dynamic_graph
 
 
 def get_version() -> str:
